API Reference
=============

This page provides comprehensive API documentation for all modules in the pydantic-ai-toolsets package.

Main Package
------------

.. automodule:: pydantic_ai_toolsets
   :members:
   :undoc-members:
   :show-inheritance:

Reasoning & Thinking Toolsets
------------------------------

Chain of Thought Reasoning
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.chain_of_thought_reasoning
   :members:
   :undoc-members:
   :show-inheritance:

Tree of Thought Reasoning
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.tree_of_thought_reasoning
   :members:
   :undoc-members:
   :show-inheritance:

Graph of Thought Reasoning
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.graph_of_thought_reasoning
   :members:
   :undoc-members:
   :show-inheritance:

Beam Search Reasoning
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.beam_search_reasoning
   :members:
   :undoc-members:
   :show-inheritance:

Monte Carlo Tree Search Reasoning
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.monte_carlo_reasoning
   :members:
   :undoc-members:
   :show-inheritance:

Reflection & Refinement Toolsets
---------------------------------

Reflection
~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.reflection
   :members:
   :undoc-members:
   :show-inheritance:

Self-Refine
~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.self_refine
   :members:
   :undoc-members:
   :show-inheritance:

Self-Ask
~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.self_ask
   :members:
   :undoc-members:
   :show-inheritance:

Multi-Agent Toolsets
--------------------

Multi-Persona Analysis
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.multi_persona_analysis
   :members:
   :undoc-members:
   :show-inheritance:

Multi-Persona Debate
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.multi_persona_debate
   :members:
   :undoc-members:
   :show-inheritance:

Utility Toolsets
----------------

Search
~~~~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.search
   :members:
   :undoc-members:
   :show-inheritance:

Todo
~~~~

.. automodule:: pydantic_ai_toolsets.toolsets.to_do
   :members:
   :undoc-members:
   :show-inheritance:

Meta-Orchestrator
-----------------

.. automodule:: pydantic_ai_toolsets.toolsets.meta_orchestrator
   :members:
   :undoc-members:
   :show-inheritance:

Shared Utilities
----------------

.. automodule:: pydantic_ai_toolsets.toolsets._shared.aliasing
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pydantic_ai_toolsets.toolsets._shared.linking
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pydantic_ai_toolsets.toolsets._shared.metrics
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pydantic_ai_toolsets.toolsets._shared.system_prompts
   :members:
   :undoc-members:
   :show-inheritance:
